@@ -15,21 +15,13 @@ public class vtkZLibDataCompressor extends vtkDataCompressor
   public int IsA(String id0)
     { return IsA_1(id0); }
 
-  private native void SetCompressionLevel_2(int id0);
-  public void SetCompressionLevel(int id0)
-    { SetCompressionLevel_2(id0); }
-
-  private native int GetCompressionLevelMinValue_3();
-  public int GetCompressionLevelMinValue()
-    { return GetCompressionLevelMinValue_3(); }
-
-  private native int GetCompressionLevelMaxValue_4();
-  public int GetCompressionLevelMaxValue()
-    { return GetCompressionLevelMaxValue_4(); }
-
-  private native int GetCompressionLevel_5();
+  private native int GetCompressionLevel_2();
   public int GetCompressionLevel()
-    { return GetCompressionLevel_5(); }
+    { return GetCompressionLevel_2(); }
+
+  private native void SetCompressionLevel_3(int id0);
+  public void SetCompressionLevel(int id0)
+    { SetCompressionLevel_3(id0); }
 
   public vtkZLibDataCompressor() { super(); }
 
